==> topia-service-replication-2.4.1-sources.jar: org/nuiton/topia/replication/operation/DettachDependency.java <==
/*
 * #%L
 * ToPIA :: Service Replication
 * 
 * $Id: DettachDependency.java 1894 2010-04-15 15:44:51Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.4.1/topia-service-replication/src/main/java/org/nuiton/topia/replication/operation/DettachDependency.java $
 * %%
 * Copyright (C) 2004 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.topia.replication.operation;

import org.nuiton.topia.replication.*;
import java.util.List;
import java.util.Map;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.framework.TopiaContextImplementor;
import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.replication.model.ReplicationModel;
import org.nuiton.topia.replication.model.ReplicationNode;
import org.nuiton.topia.replication.model.ReplicationOperationDef;
import org.nuiton.topia.replication.model.ReplicationOperationPhase;
import static org.nuiton.i18n.I18n._;

/**
 * Pour dettacher une dependance.
 *
 * TODO Pas implante pour le moment
 *
 * Note : cette operation est interne, et n'est pas creable par
 * l'utilisateur via la methode
 * {@link #register(ReplicationModel, ReplicationNode, ReplicationOperationPhase, Object...)}.
 * 
 * @author chemit
 */
public class DettachDependency implements TopiaReplicationOperation {

    @Override
    public void register(ReplicationModel model, ReplicationNode ownerNode, ReplicationOperationPhase phase, Object... parameters) {

        throw new UnsupportedOperationException(_("topia.replication.operation.error.uncreatable", getClass()));
    }

    @Override
    public void run(ReplicationOperationDef operationDef,
            TopiaContextImplementor srcCtxt,
            TopiaContextImplementor dstCtxt,
            List<? extends TopiaEntity> nodeEntities,
            Map<Class<? extends TopiaEntity>, List<String>> data) throws TopiaException {

        throw new UnsupportedOperationException(_("topia.replication.operation.error.notImplemented", getClass()));
        //TODO non implante pour le moment
//
//        ReplicationNode node = operationDef.getNode();
//
//        String[] names = (String[]) operationDef.getParameters();
//
//        EntityOperator<? super TopiaEntity> operator = node.getOperator();
//
////        // recuperation des donnees a traiter
////        List<TopiaEntity> entities = data.get(operator.getClazz());
////
////        // recuperation de la liste sur le context actuel
////        entities = ReplicationEngine.getEntities(srcCtxt, entities, false);
//
//        // dettach les attributs
//        for (TopiaEntity e : nodeEntities) {
//            for (String name : names) {
//                operator.setNull(name, e);
//            }
//        }
    }
}

==> topia-service-replication-2.4.2-sources.jar: org/nuiton/topia/replication/operation/DettachDependency.java <==
/*
 * #%L
 * ToPIA :: Service Replication
 * 
 * $Id: DettachDependency.java 2089 2010-07-26 14:07:15Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.4.2/topia-service-replication/src/main/java/org/nuiton/topia/replication/operation/DettachDependency.java $
 * %%
 * Copyright (C) 2004 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.topia.replication.operation;

import org.nuiton.topia.TopiaException;
import org.nuiton.topia.framework.TopiaContextImplementor;
import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.replication.TopiaReplicationOperation;
import org.nuiton.topia.replication.model.ReplicationModel;
import org.nuiton.topia.replication.model.ReplicationNode;
import org.nuiton.topia.replication.model.ReplicationOperationDef;
import org.nuiton.topia.replication.model.ReplicationOperationPhase;

import java.util.List;
import java.util.Map;

import static org.nuiton.i18n.I18n._;

/**
 * Pour dettacher une dependance.
 * <p/>
 * TODO Pas implante pour le moment
 * <p/>
 * Note : cette operation est interne, et n'est pas creable par
 * l'utilisateur via la methode
 * {@link #register(ReplicationModel, ReplicationNode, ReplicationOperationPhase, Object...)}.
 *
 * @author chemit
 */
public class DettachDependency implements TopiaReplicationOperation {

    @Override
    public void register(ReplicationModel model, ReplicationNode ownerNode, ReplicationOperationPhase phase, Object... parameters) {

        throw new UnsupportedOperationException(_("topia.replication.operation.error.uncreatable", getClass()));
    }

    @Override
    public void run(ReplicationOperationDef operationDef,
                    TopiaContextImplementor srcCtxt,
                    TopiaContextImplementor dstCtxt,
                    List<? extends TopiaEntity> nodeEntities,
                    Map<Class<? extends TopiaEntity>, List<String>> data) throws TopiaException {

        throw new UnsupportedOperationException(_("topia.replication.operation.error.notImplemented", getClass()));
        //TODO non implante pour le moment
//
//        ReplicationNode node = operationDef.getNode();
//
//        String[] names = (String[]) operationDef.getParameters();
//
//        EntityOperator<? super TopiaEntity> operator = node.getOperator();
//
////        // recuperation des donnees a traiter
////        List<TopiaEntity> entities = data.get(operator.getClazz());
////
////        // recuperation de la liste sur le context actuel
////        entities = ReplicationEngine.getEntities(srcCtxt, entities, false);
//
//        // dettach les attributs
//        for (TopiaEntity e : nodeEntities) {
//            for (String name : names) {
//                operator.setNull(name, e);
//            }
//        }
    }
}
